<?php
if (!(defined('_VALID_CB') || defined('_JEXEC') || defined('_VALID_MOS')))
{
	die('Direct Access to this location is not allowed.');
}

class getSubscriptionHistoryTab extends cbTabHandler
{
	/**
	 * Constructor
	 */
	public function getSubscriptionHistoryTab()
	{
		$this->cbTabHandler();
	}

	/**
	 * Display subscription history of a user
	 *
	 * @param $tab
	 * @param $user
	 * @param $ui
	 *
	 * @return string
	 */
	public function getDisplayTab($tab, $user, $ui)
	{
		$params = $this->params;
		$db     = JFactory::getDbo();
		$query  = $db->getQuery(true);

		// Get total subscription records
		$query->select('COUNT(*)')
			->from('#__osmembership_subscribers AS tbl')
			->where('tbl.user_id = '. (int) $user->id);
		$db->setQuery($query);
		$total = (int) $db->loadResult();

		// Get the subscription records
		$query->clear();
		$query->select('tbl.*')
			->select('b.title AS plan_title, b.lifetime_membership, b.enable_renewal, b.recurring_subscription')
			->from('#__osmembership_subscribers AS tbl')
			->leftJoin('#__osmembership_plans AS b  ON tbl.plan_id = b.id')
			->where('tbl.user_id = '. (int) $user->id)
			->order('tbl.id');

		$numberRecords = (int) $params->get('number_records', 10);
		$pagingParams      = $this->_getPaging(array(), array("entries_"));
		if ($pagingParams["entries_limitstart"] === null)
		{
			$pagingParams["entries_limitstart"] = "0";
		}
		if ($numberRecords > $total)
		{
			$pagingParams["entries_limitstart"] = "0";
		}

		$limitStart = $pagingParams["entries_limitstart"] ? $pagingParams["entries_limitstart"] : 0;
		$db->setQuery($query, $limitStart, $numberRecords);
		$rows = $db->loadObjectList();
		ob_start();
		$this->drawSubscriptionHistory($rows, $pagingParams, $numberRecords, $total);
		$return = ob_get_contents();
		ob_end_clean();

		return $return;
	}

	/**
	 * Draw the output for subscription history
	 *
	 * @param array $rows
	 */
	private function drawSubscriptionHistory($rows, $pagingParams, $numberRecords, $total)
	{
		//Load language file here
		require_once JPATH_ROOT . '/components/com_osmembership/helper/route.php';
		require_once JPATH_ROOT . '/components/com_osmembership/helper/helper.php';
		$config = OSMembershipHelper::getConfig();
		$Itemid = OSMembershipHelper::getItemid();
		OSMembershipHelper::loadLanguage();
		if (count($rows))
		{
			$cols = 4;
		?>
			<table class="table table-striped table-bordered table-condensed">
				<thead>
					<tr>
						<th>
							<?php echo JText::_('OSM_PLAN') ?>
						</th>
						<th class="center">
							<?php echo JText::_('OSM_ACTIVATE_TIME') ; ?>
						</th>
						<th style="text-align: right;" class="hidden-phone">
							<?php echo JText::_('OSM_GROSS_AMOUNT') ; ?>
						</th>
						<th class="hidden-phone">
							<?php echo JText::_('OSM_SUBSCRIPTION_STATUS'); ?>
						</th>
						<?php
						if ($config->activate_invoice_feature)
						{
							$cols++ ;
						?>
							<th class="hidden-phone" class="center">
								<?php echo JText::_('OSM_INVOICE_NUMBER') ; ?>
							</th>
						<?php
						}
						?>
					</tr>
				</thead>
				<tbody>
				<?php
				for ($i = 0, $n = count($rows); $i < $n; $i++)
				{
					$row = $rows[$i];
					$link = JRoute::_('index.php?option=com_osmembership&view=subscription&id='.$row->id.'&Itemid='.$Itemid);
					?>
					<tr>
						<td>
							<a href="<?php echo $link; ?>"><?php echo $row->plan_title; ?></a>
						</td>
						<td class="center">
							<strong><?php echo JHtml::_('date', $row->from_date, $config->date_format); ?></strong> To
							<strong>
								<?php
								if ($row->lifetime_membership)
								{
									echo JText::_('OSM_LIFETIME');
								}
								else
								{
									echo JHtml::_('date', $row->to_date, $config->date_format);
								}
								?>
							</strong>
						</td>
						<td style="text-align: right;" class="hidden-phone">
							<?php echo $config->currency_symbol.number_format($row->gross_amount, 2) ; ?>
						</td>
						<td class="hidden-phone">
							<?php
								switch ($row->published)
								{
									case 0 :
										echo JText::_('OSM_PENDING');
										break ;
									case 1 :
										echo JText::_('OSM_ACTIVE');
										break ;
									case 2 :
										echo JText::_('OSM_EXPIRED');
										break ;
									case 3 :
										echo JText::_('OSM_CANCELLED_PENDING');
										break ;
									case 4 :
										echo JText::_('OSM_CANCELLED_REFUNDED');
										break ;
								}
							?>
						</td>
						<?php
						if ($config->activate_invoice_feature)
						{
						?>
							<td class="center" class="hidden-phone">
								<?php
								if ($row->invoice_number)
								{
								?>
									<a href="<?php echo JRoute::_('index.php?option=com_osmembership&task=download_invoice&id='.$row->id); ?>" title="<?php echo JText::_('OSM_DOWNLOAD'); ?>"><?php echo OSMembershipHelper::formatInvoiceNumber($row, $config) ; ?></a>
								<?php
								}
								?>
							</td>
						<?php
						}
						?>
					</tr>
					<?php
				}
			?>
			</tbody>
			<?php
				if ($total > $numberRecords)
				{
				?>
				<tfoot>
					<tr>
						<td colspan="<?php echo $cols; ?>">
							<div
								align="center"><?php echo $this->_writePaging($pagingParams, "entries_", $numberRecords, $total); ?></div>
						</td>
					</tr>
				</tfoot>
				<?php
				}
				?>
			</table>
		<?php
		}
	}
}
?>